@@ -16,7 +16,7 @@ Readonly::Scalar my $TYPE_DEFAULT => 'Die';
 Readonly::Scalar my $LEVEL_DEFAULT => 4;
 
 # Version.
-our $VERSION = 0.22;
+our $VERSION = 0.23;
 
 # Type of error.
 our $TYPE = $TYPE_DEFAULT;
@@ -217,22 +217,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Error::Pure>,
-L<Error::Pure::AllError>,
-L<Error::Pure::Always>,
-L<Error::Pure::Die>,
-L<Error::Pure::Error>,
-L<Error::Pure::ErrorList>,
-L<Error::Pure::HTTP::AllError>,
-L<Error::Pure::HTTP::Error>,
-L<Error::Pure::HTTP::ErrorList>,
-L<Error::Pure::HTTP::JSON>,
-L<Error::Pure::HTTP::Print>,
-L<Error::Pure::JSON>,
-L<Error::Pure::Output::JSON>,
-L<Error::Pure::Output::Text>,
-L<Error::Pure::Print>,
-L<Error::Pure::PrintVar>.
+=over
+
+=item L<Task::Error::Pure>
+
+Install the Error::Pure modules.
+
+=back
 
 =head1 ACKNOWLEDGMENTS
 
@@ -255,6 +246,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.22
+0.23
 
 =cut
