@@ -17,7 +17,7 @@ Readonly::Scalar my $EMPTY_STR => q{};
 Readonly::Scalar my $EVAL => 'eval {...}';
 
 # Version.
-our $VERSION = 0.22;
+our $VERSION = 0.23;
 
 # Process error.
 sub err {
@@ -137,18 +137,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Error::Pure>,
-L<Error::Pure::AllError>,
-L<Error::Pure::Die>,
-L<Error::Pure::Error>,
-L<Error::Pure::ErrorList>,
-L<Error::Pure::HTTP::AllError>,
-L<Error::Pure::HTTP::Error>,
-L<Error::Pure::HTTP::ErrorList>,
-L<Error::Pure::HTTP::Print>,
-L<Error::Pure::Output::Text>,
-L<Error::Pure::PrintVar>,
-L<Error::Pure::Utils>.
+=over
+
+=item L<Task::Error::Pure>
+
+Install the Error::Pure modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -162,11 +157,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2008-2014 Michal Špaček
+ © 2008-2015 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.22
+0.23
 
 =cut
